@@ -1,17 +1,17 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-06-08 19:13:07 michl>
+# Last changed Time-stamp: <2017-06-10 19:08:23 michl>
 
 package Bio::ViennaNGS::Peak;
 
-use version; our $VERSION = qv('0.17');
+use Bio::ViennaNGS;
 use Moose;
 use Carp;
 use Data::Dumper;
 use Path::Class;
 use List::Util qw(sum sum0 min max first);
 use Bio::ViennaNGS::Util qw(sortbed);
-
 use namespace::autoclean;
+use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 has 'data' => (
 	       is => 'ro',
